@@ -13,8 +13,9 @@ applications_list() {
 		# The following expression matches:
 		# - APP_xxx_EXE
 		# - APP_xxx_SCUMMID
+		# - APP_xxx_TYPE
 		# and the suffixed variants of these variables.
-		sed_expression='s/^\(APP_[0-9A-Z]\+\)_\(EXE\|SCUMMID\)\(_[0-9A-Z]\+\)*=.*/\1/p'
+		sed_expression='s/^\(APP_[0-9A-Z]\+\)_\(EXE\|SCUMMID\|TYPE\)\(_[0-9A-Z]\+\)*=.*/\1/p'
 		applications_list=$(set | sed --silent --expression="$sed_expression")
 	fi
 
@@ -33,12 +34,7 @@ applications_list() {
 		esac
 	fi
 
-	# Always return a list with no duplicate entry,
-	# excluding empty lines.
-	# Ignore grep error return if there is nothing to print.
-	printf '%s\n' $applications_list | \
-		sort --unique | \
-		grep --invert-match --regexp='^$' || true
+	printf '%s\n' $applications_list | list_clean
 }
 
 # Print the type of prefix to use for the given application.
@@ -70,6 +66,9 @@ application_prefix_type() {
 		local application_type
 		application_type=$(application_type "$application")
 		case "$application_type" in
+			('renpy')
+				prefix_type='none'
+			;;
 			('scummvm')
 				prefix_type='none'
 			;;
@@ -260,18 +259,20 @@ application_prerun() {
 	local application
 	application="$1"
 
-	# Scripts for DOSBox games targeting a compatibility level < 2.20 have no support for regular pre-run actions.
-	if ! compatibility_level_is_at_least '2.20'; then
-		local application_type
-		application_type=$(application_type "$application")
-		if [ "$application_type" = 'dosbox' ]; then
-			return 0
-		fi
-	fi
-
 	local application_prerun
 	application_prerun=$(context_value "${application}_PRERUN")
 
+	# Run engine specific actions
+	local game_engine
+	game_engine=$(game_engine)
+	case "$game_engine" in
+		('unity3d')
+			## Use a dedicated log file for the current game session.
+			application_prerun="$application_prerun
+			mkdir --parents logs"
+		;;
+	esac
+
 	# If LD_PRELOAD hacks are provided in the current package, include them in the pre-run actions.
 	local package hacks_list
 	package=$(current_package)
@@ -297,15 +298,6 @@ application_postrun() {
 	local application
 	application="$1"
 
-	# Scripts for DOSBox games targeting a compatibility level < 2.20 have no support for regular post-run actions.
-	if ! compatibility_level_is_at_least '2.20'; then
-		local application_type
-		application_type=$(application_type "$application")
-		if [ "$application_type" = 'dosbox' ]; then
-			return 0
-		fi
-	fi
-
 	local application_postrun
 	application_postrun=$(context_value "${application}_POSTRUN")
 
@@ -323,6 +315,17 @@ application_options() {
 	application="$1"
 	application_options=$(context_value "${application}_OPTIONS")
 
+	# Add engine specific options
+	local game_engine
+	game_engine=$(game_engine)
+	case "$game_engine" in
+		('unity3d')
+			## Use a dedicated log file for the current game session.
+			## The quotes are not truly required, but they make ShellCheck happy.
+			application_options="$application_options -logFile \"./logs/\$(date +%F-%R).log\""
+		;;
+	esac
+
 	# Check that the options string does not span multiple lines
 	local line_breaks_number
 	line_breaks_number=$(printf '%s' "$application_options" | wc --lines)
