@@ -1,3 +1,53 @@
+# Fetch icon files, convert them to the expected format, include them in the given package.
+#
+# This function is the one that should be called from game scripts,
+# it can take several applications as its arguments,
+# and default to handle all applications if none are explicitely given.
+#
+# USAGE: content_inclusion_icons [$package [$application…]]
+content_inclusion_icons() {
+	# Do nothing if icons inclusion has been disabled.
+	local option_icons
+	option_icons=$(option_value 'icons')
+	if [ "$option_icons" -eq 0 ]; then
+		return 0
+	fi
+
+	# Get the package that should include the icons.
+	local package
+	if [ $# -ge 1 ]; then
+		package="$1"
+		shift 1
+	else
+		package=$(current_package)
+	fi
+
+	# If an optional icons archive has been provided, use that instead of the icons shipped with the game
+	if archive_is_available 'ARCHIVE_ICONS'; then
+		content_inclusion_optional_icons_archive "$package"
+		## Return early if an optional icons archive has been used.
+		return 0
+	fi
+
+	# If no applications are explicitely listed,
+	# try to fetch the icons for all applications.
+	if [ "$#" -eq 0 ]; then
+		applications_list=$(applications_list)
+		## If content_inclusion_icons has been called with no argument, the applications list should not be empty.
+		if [ -z "$applications_list" ]; then
+			error_applications_list_empty
+			return 1
+		fi
+		content_inclusion_icons "$package" $applications_list
+		return 0
+	fi
+
+	local application
+	for application in "$@"; do
+		icons_inclusion_single_application "$package" "$application"
+	done
+}
+
 # Fetch files from the archive, and include them into the package skeleton.
 # A list of default content identifiers is used.
 # USAGE: content_inclusion_default
@@ -12,10 +62,22 @@ content_inclusion_default() {
 			content_inclusion_unity3d_plugins "$package"
 		fi
 		content_inclusion_default_libraries "$package"
+		content_inclusion_default_fonts "$package"
 		content_inclusion_default_game_data "$package"
 		content_inclusion_default_documentation "$package"
 	done
 
+	# Including files used to apply tweaks to the WINE prefix should only be done in the packages including the game binaries.
+	local package_architecture
+	for package in $packages_list; do
+		package_architecture=$(package_architecture "$package")
+		case "$package_architecture" in
+			('64'|'32')
+				content_inclusion_wineprefix_tweaks "$package"
+			;;
+		esac
+	done
+
 	# content_inclusion_extra_libraries must be called in its own loop, at the end of the content inclusion process.
 	# Since it can trigger an archive_extraction call leading to a set_standard_permissions call,
 	# calling it earlier could lead to unwanted permissions reset.
@@ -59,6 +121,29 @@ content_inclusion_default_libraries() {
 	done
 }
 
+# Fetch files from the archive, and include them into the package skeleton.
+# A list of default content identifiers is used, limited to TTF fonts for a single package.
+# USAGE: content_inclusion_default_fonts $package
+content_inclusion_default_fonts() {
+	local package package_suffix
+	package="$1"
+	package_suffix="${package#PKG_}"
+
+	local target_directory
+	target_directory=$(path_fonts_ttf)
+
+	content_inclusion "FONTS_${package_suffix}" "$package" "$target_directory"
+	local index files_list
+	for index in $(seq 0 9); do
+		# Stop looping at the first unset files list
+		files_list=$(context_name "CONTENT_FONTS${index}_${package_suffix}_FILES")
+		if [ -z "$files_list" ]; then
+			break
+		fi
+		content_inclusion "FONTS${index}_${package_suffix}" "$package" "$target_directory"
+	done
+}
+
 # Fetch files from the archive, and include them into the package skeleton.
 # A list of default content identifiers is used, limited to game data files for a single package.
 # USAGE: content_inclusion_default_game_data $package
