@@ -4,8 +4,9 @@ information_huge_file_split() {
 	local path_file
 	path_file="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Découpage de %s en plusieurs fichiers…\n'
 		;;
