@@ -6,6 +6,7 @@ packages_generation() {
 		local packages_list
 		packages_list=$(packages_list)
 		packages_generation $packages_list
+		return 0
 	fi
 
 	local option_package
@@ -102,31 +103,6 @@ package_is_included_in_packages_list() {
 		grep --quiet --fixed-strings --word-regexp "$package"
 }
 
-# Print the list of all the packages that could be built from the current game script,
-# not restricted to the current archive.
-# USAGE: packages_list_all_archives
-# RETURN: a list of package identifiers,
-#         separated by line breaks,
-#         without duplicates
-packages_list_all_archives() {
-	# List the packages that could be generated for each supported archive.
-	# This list will include duplicates.
-	local archives_list packages_list
-	archives_list=$(archives_return_list)
-	packages_list=$(
-		for archive in $archives_list; do
-			set_current_archive "$archive"
-			packages_list
-		done
-	)
-
-	## TODO: This output sanitizing should be moved to a dedicated function.
-	# Print the full list of packages, one per line, with no duplicates.
-	printf '%s\n' $packages_list | \
-		grep --invert-match --regexp='^$' | \
-		sort --unique
-}
-
 # Print the list of the packages that would be generated from the given archive.
 # USAGE: packages_print_list $archive
 # RETURN: a list of package file names, one per line
@@ -177,7 +153,12 @@ package_id() {
 
 	# Fall back on the game id if no package id is explicitly set
 	if [ -z "$package_id" ]; then
-		package_id=$(game_id)
+		## We need to explicitly set the context here,
+		## because the value of GAME_ID might be specific to the current package.
+		package_id=$(
+			set_current_package "$package"
+			game_id
+		)
 		## Include the expansion id if one is available.
 		local expansion_id
 		expansion_id=$(expansion_id)
@@ -230,30 +211,6 @@ package_architecture() {
 	printf '%s' "$package_architecture"
 }
 
-# Print the architecture string of the given package, in the format expected by the packages manager
-# USAGE: package_architecture_string $package
-# RETURNS: the package architecture, in the format expected by the packages manager
-package_architecture_string() {
-	local package
-	package="$1"
-
-	local option_package package_architecture_string
-	option_package=$(option_value 'package')
-	case "$option_package" in
-		('arch')
-			package_architecture_string=$(archlinux_package_architecture_string "$package")
-		;;
-		('deb')
-			package_architecture_string=$(debian_package_architecture_string "$package")
-		;;
-		('gentoo'|'egentoo')
-			package_architecture_string=$(gentoo_package_architecture_string "$package")
-		;;
-	esac
-
-	printf '%s' "$package_architecture_string"
-}
-
 # Print the desciption of the given package
 # USAGE: package_description $package
 # RETURNS: the package description, a non-empty string that should not include line breaks
@@ -456,10 +413,7 @@ package_provides() {
 		return 0
 	fi
 
-	# Skip empty lines,
-	# ignore grep error state if there is nothing to return.
-	printf '%s' "$package_provides" | \
-		grep --invert-match --regexp='^$' || true
+	printf '%s' "$package_provides" | list_clean
 }
 
 # Print the actions that should be run post-installation for the given package
