@@ -20,13 +20,7 @@ dependencies_list_generic() {
 		esac
 	fi
 
-	## TODO: This output sanitizing should be moved to a dedicated function.
-	# Always return a list with no duplicate entry, excluding empty lines.
-	# Ignore grep error return if there is nothing to print.
-	printf '%s' "$dependencies_generic" | \
-		sed 's/ /\n/g' | \
-		sort --unique | \
-		grep --invert-match --regexp='^$' || true
+	printf '%s' "$dependencies_generic" | sed 's/ /\n/g' | list_clean
 }
 
 # Add a dependency to the list of the given package.
@@ -47,3 +41,4 @@ dependencies_add_generic() {
 	fi
 	export $dependencies_variable_name="$current_dependencies $dependency"
 }
+
