@@ -4,8 +4,9 @@ information_package_already_exists() {
 	local file
 	file="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='%s existe déjà.\n'
 		;;
@@ -23,8 +24,9 @@ information_package_building() {
 	local file
 	file="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Construction de %s…\n'
 		;;
@@ -42,8 +44,9 @@ error_package_id_invalid() {
 	local package_id
 	package_id="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='Lʼid de paquet fourni ne correspond pas au format attendu : "%s"\n'
 			message="$message"'Cette valeur ne peut utiliser que des caractères du set [-a-z0-9],'
@@ -65,8 +68,9 @@ error_package_generation_failed() {
 	local package_name
 	package_name="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La génération du paquet suivant a échoué : %s\n'
 			message="$message"'Merci de signaler cet échec sur notre système de suivi : %s\n\n'
@@ -87,8 +91,9 @@ error_package_metadata_generation_failed() {
 	local package_name
 	package_name="$1"
 
-	local message
-	case "${LANG%_*}" in
+	local messages_language message
+	messages_language=$(messages_language)
+	case "$messages_language" in
 		('fr')
 			message='La génération des méta-données du paquet suivant a échoué : %s\n'
 		;;
