@@ -42,15 +42,10 @@ java_launcher_environment() {
 	local application
 	application="$1"
 
-	local game_id path_game application_exe application_options application_java_options
+	local game_id path_game application_exe
 	game_id=$(game_id)
 	path_game=$(path_game_data)
 	application_exe=$(application_exe_escaped "$application")
-	application_options=$(application_options "$application")
-	application_java_options=$(application_java_options "$application")
-	## Legacy variable APP_xxx_LIBS should not be used with compatibility level ≥ 2.19,
-	## a warning will be trigerred is it is set.
-	application_libs=$(application_libs_legacy "$application")
 
 	cat <<- EOF
 	# Set the environment
@@ -58,9 +53,6 @@ java_launcher_environment() {
 	GAME_ID='$game_id'
 	PATH_GAME='$path_game'
 	APP_EXE='$application_exe'
-	APP_OPTIONS="$application_options"
-	JAVA_OPTIONS='$application_java_options'
-	APP_LIBS='$application_libs'
 
 	EOF
 }
@@ -88,10 +80,9 @@ java_launcher_run() {
 	## to ensure post-run commands are run.
 	set +o errexit
 
-	## Silence ShellCheck false-positive
-	## Double quote to prevent globbing and word splitting.
-	# shellcheck disable=SC2086
-	java $JAVA_OPTIONS -jar "$APP_EXE" $APP_OPTIONS "$@"
+	EOF
+	game_exec_line "$application"
+	cat <<- 'EOF'
 
 	game_exit_status=$?
 	set -o errexit
@@ -100,3 +91,19 @@ java_launcher_run() {
 
 	application_postrun "$application"
 }
+
+# Java - Print the line starting the game
+# USAGE: java_exec_line $application
+# RETURN: the command to execute, including its command line options
+java_exec_line() {
+	local application
+	application="$1"
+
+	local application_java_options application_options
+	application_java_options=$(application_java_options "$application")
+	application_options=$(application_options "$application")
+	cat <<- EOF
+	java $application_java_options -jar "\$APP_EXE" $application_options "\$@"
+	EOF
+}
+
