@@ -150,7 +150,7 @@ test_application_exe_path() {
 	PKG_MAIN_ID='some-game-main'
 	application_exe_path=$(application_exe_path "$APP_MAIN_EXE")
 	assertEquals "${PLAYIT_WORKDIR}/packages/some-game-main_1.0-1+19700101.1_all/usr/share/games/some-game/SomeGame.exe" "$application_exe_path"
-	unset PKG PKG_MAIN_ID
+	unset PKG PKG_MAIN_ID PLAYIT_CONTEXT_PACKAGE
 
 	# Look in all packages
 	PACKAGES_LIST='
@@ -199,13 +199,6 @@ test_application_prerun() {
 	application_prerun=$(application_prerun 'APP_MAIN')
 	assertEquals 'some commands' "$application_prerun"
 
-	# For DOSBox games targeting ./play.it ≤ 2.19, APP_xxx_PRERUN should be ignored here
-	PLAYIT_COMPATIBILITY_LEVEL='2.19'
-	APP_MAIN_TYPE='dosbox'
-	application_prerun=$(application_prerun 'APP_MAIN')
-	assertNull "$application_prerun"
-	unset PLAYIT_COMPATIBILITY_LEVEL APP_MAIN_TYPE
-
 	# Check that LD_PRELOAD hacks are automatically added
 	hacks_included_in_package() {
 		printf '%s\n' 'HACK_SDL1COMPAT' 'HACK_NOATIME'
@@ -235,12 +228,6 @@ test_application_postrun() {
 	APP_MAIN_POSTRUN='some commands'
 	application_postrun=$(application_postrun 'APP_MAIN')
 	assertEquals 'some commands' "$application_postrun"
-
-	# For DOSBox games targeting ./play.it ≤ 2.19, APP_xxx_POSTRUN should be ignored here
-	PLAYIT_COMPATIBILITY_LEVEL='2.19'
-	APP_MAIN_TYPE='dosbox'
-	application_postrun=$(application_postrun 'APP_MAIN')
-	assertNull "$application_postrun"
 }
 
 test_application_options() {
